Subject: [PATCH v2 04/19] build: julia-build-system: Fix corner-case for parallel tests.

From: zimoun <[email-masked]>
Date: Wed, 23 Feb 2022 14:47:07 +0100

* guix/build/julia-build-system.scm (check): Do not run parallel tests when
'--cores=1'.
---
 guix/build/julia-build-system.scm | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/guix/build/julia-build-system.scm b/guix/build/julia-build-system.scm
index c5ad65d029..b0dac154e9 100644
--- a/guix/build/julia-build-system.scm
+++ b/guix/build/julia-build-system.scm
@@ -112,9 +112,9 @@ (define* (check #:key tests? source inputs outputs julia-package-name
            (job-count (if parallel-tests?
                           (parallel-job-count)
                           1))
            ;; The --proc argument of Julia *adds* extra processors rather than
            ;; specify the exact count to use, so zero must be specified to
            ;; disable parallel processing...
            (additional-procs (max 0 (1- job-count))))
       ;; With a patch, SOURCE_DATE_EPOCH is honored
       (setenv "SOURCE_DATE_EPOCH" "1")
@@ -127,7 +127,7 @@ (define* (check #:key tests? source inputs outputs julia-package-name
       (setenv "HOME" "/tmp")
       (apply invoke "julia"
              `("--depwarn=yes"
-               ,@(if parallel-tests?
+               ,@(if (and parallel-tests? (< 0 additional-procs))
                      ;; XXX: ... but '--procs' doesn't accept 0 as a valid
                      ;; value, so just omit the argument entirely.
                      (list (string-append  "--procs="
@@ -112,9 +112,9 @@ (define* (check #:key tests? source inputs outputs julia-package-name
                           (parallel-job-count)
                           1))
-           ;; The --proc argument of Julia *adds* extra processors rather than
-           ;; specify the exact count to use, so zero must be specified to
-           ;; disable parallel processing...
+           ;; The --procs argument of Julia *adds* extra processors rather
+           ;; than specify the exact count to use, so zero must be specified
+           ;; to disable parallel processing...
            (additional-procs (max 0 (1- job-count))))
       ;; With a patch, SOURCE_DATE_EPOCH is honored
-- 
2.34.0